@@ -3,11 +3,11 @@
 #define HOST_VENDOR "pc"
 #define HOST_OS "linux"
 #define HOST_OS_NAME "linux"
-#define HOST_OS_VERSION "2.4.9-12"
+#define HOST_OS_VERSION "2.4.9-13debug"
 #define HOST_ARCH "i386"
-#define HOST_NAME "fsl-gw.fsl.cs.sunysb.edu"
+#define HOST_NAME "dhcp9.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Wed Nov 14 17:57:19 EST 2001"
+#define CONFIG_DATE "Wed Nov 14 22:04:36 EST 2001"
 #define PACKAGE "am-utils"
 #define VERSION "6.0.8s1"
 #define PACKAGE "am-utils"
@@ -24,7 +24,7 @@
 #define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION ""
+#define HOST_HEADER_VERSION "2.4.9-13"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBNSL 1
